glinter/walker
Values
pub fn collect(module: glance.Module) -> rule.ModuleData
Walk the AST once, collecting all expressions and statements into flat lists.
pub fn collect(module: glance.Module) -> rule.ModuleData
Walk the AST once, collecting all expressions and statements into flat lists.